# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.appointments_api import AppointmentsApi  # noqa: E501


class TestAppointmentsApi(unittest.TestCase):
    """AppointmentsApi unit test stubs"""

    def setUp(self):
        self.api = AppointmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_entity_to_appointment(self):
        """Test case for add_entity_to_appointment

        Addentitytoappointment  # noqa: E501
        """
        pass

    def test_create_appointment(self):
        """Test case for create_appointment

        Createappointment  # noqa: E501
        """
        pass

    def test_delete_appointment(self):
        """Test case for delete_appointment

        Deleteappointment  # noqa: E501
        """
        pass

    def test_detach_entity_from_appointment(self):
        """Test case for detach_entity_from_appointment

        Removeentityfromappointment  # noqa: E501
        """
        pass

    def test_get_appointment(self):
        """Test case for get_appointment

        Getappointment  # noqa: E501
        """
        pass

    def test_search_appointment(self):
        """Test case for search_appointment

        Searchappointments  # noqa: E501
        """
        pass

    def test_search_appointment_entities(self):
        """Test case for search_appointment_entities

        Searchappointmententities  # noqa: E501
        """
        pass

    def test_search_entity_appointments(self):
        """Test case for search_entity_appointments

        Getentityappointments  # noqa: E501
        """
        pass

    def test_update_appointment(self):
        """Test case for update_appointment

        Updateappointment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.tags_api import TagsApi  # noqa: E501


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Createtag  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Gettag  # noqa: E501
        """
        pass

    def test_search_tag(self):
        """Test case for search_tag

        Searchtag  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Updatetag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import re  # noqa: F401
import sys  # noqa: F401
import typing  # noqa: F401
import functools  # noqa: F401

from frozendict import frozendict  # noqa: F401

import decimal  # noqa: F401
from datetime import date, datetime  # noqa: F401
from frozendict import frozendict  # noqa: F401

from ehelply_python_experimental_sdk.schemas import (  # noqa: F401
    AnyTypeSchema,
    ComposedSchema,
    DictSchema,
    ListSchema,
    StrSchema,
    IntSchema,
    Int32Schema,
    Int64Schema,
    Float32Schema,
    Float64Schema,
    NumberSchema,
    UUIDSchema,
    DateSchema,
    DateTimeSchema,
    DecimalSchema,
    BoolSchema,
    BinarySchema,
    NoneSchema,
    none_type,
    Configuration,
    Unset,
    unset,
    ComposedBase,
    ListBase,
    DictBase,
    NoneBase,
    StrBase,
    IntBase,
    Int32Base,
    Int64Base,
    Float32Base,
    Float64Base,
    NumberBase,
    UUIDBase,
    DateBase,
    DateTimeBase,
    BoolBase,
    BinaryBase,
    Schema,
    _SchemaValidator,
    _SchemaTypeChecker,
    _SchemaEnumMaker
)


class Pagination(
    DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Pagination state
    """
    _required_property_names = set((
        'current_page',
        'page_size',
        'total_items',
        'total_pages',
        'has_previous_page',
        'has_next_page',
    ))
    current_page = IntSchema
    page_size = IntSchema
    total_items = IntSchema
    total_pages = IntSchema
    has_previous_page = BoolSchema
    has_next_page = BoolSchema
    previous_page = IntSchema
    next_page = IntSchema


    def __new__(
        cls,
        *args: typing.Union[dict, frozendict, ],
        current_page: current_page,
        page_size: page_size,
        total_items: total_items,
        total_pages: total_pages,
        has_previous_page: has_previous_page,
        has_next_page: has_next_page,
        previous_page: typing.Union[previous_page, Unset] = unset,
        next_page: typing.Union[next_page, Unset] = unset,
        _configuration: typing.Optional[Configuration] = None,
        **kwargs: typing.Type[Schema],
    ) -> 'Pagination':
        return super().__new__(
            cls,
            *args,
            current_page=current_page,
            page_size=page_size,
            total_items=total_items,
            total_pages=total_pages,
            has_previous_page=has_previous_page,
            has_next_page=has_next_page,
            previous_page=previous_page,
            next_page=next_page,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.staff_api_endpoints.create_staff import CreateStaff
from ehelply_python_experimental_sdk.api.staff_api_endpoints.delete_staff import DeleteStaff
from ehelply_python_experimental_sdk.api.staff_api_endpoints.get_staff import GetStaff
from ehelply_python_experimental_sdk.api.staff_api_endpoints.search_staff import SearchStaff
from ehelply_python_experimental_sdk.api.staff_api_endpoints.update_staff import UpdateStaff


class StaffApi(
    CreateStaff,
    DeleteStaff,
    GetStaff,
    SearchStaff,
    UpdateStaff,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.add_entity_to_appointment import AddEntityToAppointment
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.create_appointment import CreateAppointment
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.delete_appointment import DeleteAppointment
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.detach_entity_from_appointment import DetachEntityFromAppointment
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.get_appointment import GetAppointment
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.search_appointment import SearchAppointment
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.search_appointment_entities import SearchAppointmentEntities
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.search_entity_appointments import SearchEntityAppointments
from ehelply_python_experimental_sdk.api.appointments_api_endpoints.update_appointment import UpdateAppointment


class AppointmentsApi(
    AddEntityToAppointment,
    CreateAppointment,
    DeleteAppointment,
    DetachEntityFromAppointment,
    GetAppointment,
    SearchAppointment,
    SearchAppointmentEntities,
    SearchEntityAppointments,
    UpdateAppointment,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import re  # noqa: F401
import sys  # noqa: F401
import typing  # noqa: F401
import functools  # noqa: F401

from frozendict import frozendict  # noqa: F401

import decimal  # noqa: F401
from datetime import date, datetime  # noqa: F401
from frozendict import frozendict  # noqa: F401

from ehelply_python_experimental_sdk.schemas import (  # noqa: F401
    AnyTypeSchema,
    ComposedSchema,
    DictSchema,
    ListSchema,
    StrSchema,
    IntSchema,
    Int32Schema,
    Int64Schema,
    Float32Schema,
    Float64Schema,
    NumberSchema,
    UUIDSchema,
    DateSchema,
    DateTimeSchema,
    DecimalSchema,
    BoolSchema,
    BinarySchema,
    NoneSchema,
    none_type,
    Configuration,
    Unset,
    unset,
    ComposedBase,
    ListBase,
    DictBase,
    NoneBase,
    StrBase,
    IntBase,
    Int32Base,
    Int64Base,
    Float32Base,
    Float64Base,
    NumberBase,
    UUIDBase,
    DateBase,
    DateTimeBase,
    BoolBase,
    BinaryBase,
    Schema,
    _SchemaValidator,
    _SchemaTypeChecker,
    _SchemaEnumMaker
)


class Field(
    DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Field
    """
    uuid = StrSchema
    type = IntSchema
    placeholder = StrSchema

    @classmethod
    @property
    def validations(cls) -> typing.Type['Validations']:
        return Validations
    hint = StrSchema
    icon = StrSchema
    label = StrSchema

    @classmethod
    @property
    def options(cls) -> typing.Type['Options']:
        return Options


    def __new__(
        cls,
        *args: typing.Union[dict, frozendict, ],
        uuid: typing.Union[uuid, Unset] = unset,
        type: typing.Union[type, Unset] = unset,
        placeholder: typing.Union[placeholder, Unset] = unset,
        validations: typing.Union['Validations', Unset] = unset,
        hint: typing.Union[hint, Unset] = unset,
        icon: typing.Union[icon, Unset] = unset,
        label: typing.Union[label, Unset] = unset,
        options: typing.Union['Options', Unset] = unset,
        _configuration: typing.Optional[Configuration] = None,
        **kwargs: typing.Type[Schema],
    ) -> 'Field':
        return super().__new__(
            cls,
            *args,
            uuid=uuid,
            type=type,
            placeholder=placeholder,
            validations=validations,
            hint=hint,
            icon=icon,
            label=label,
            options=options,
            _configuration=_configuration,
            **kwargs,
        )

from ehelply_python_experimental_sdk.model.options import Options
from ehelply_python_experimental_sdk.model.validations import Validations



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.reviews_api import ReviewsApi  # noqa: E501


class TestReviewsApi(unittest.TestCase):
    """ReviewsApi unit test stubs"""

    def setUp(self):
        self.api = ReviewsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_review(self):
        """Test case for create_review

        Create  # noqa: E501
        """
        pass

    def test_delete_review(self):
        """Test case for delete_review

        Deletereview  # noqa: E501
        """
        pass

    def test_get_review(self):
        """Test case for get_review

        Getreview  # noqa: E501
        """
        pass

    def test_search_reviews(self):
        """Test case for search_reviews

        Searchreview  # noqa: E501
        """
        pass

    def test_update_review(self):
        """Test case for update_review

        Updatereview  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.reviews_api_endpoints.create_review import CreateReview
from ehelply_python_experimental_sdk.api.reviews_api_endpoints.delete_review import DeleteReview
from ehelply_python_experimental_sdk.api.reviews_api_endpoints.get_review import GetReview
from ehelply_python_experimental_sdk.api.reviews_api_endpoints.search_reviews import SearchReviews
from ehelply_python_experimental_sdk.api.reviews_api_endpoints.update_review import UpdateReview


class ReviewsApi(
    CreateReview,
    DeleteReview,
    GetReview,
    SearchReviews,
    UpdateReview,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.catalogs_api import CatalogsApi  # noqa: E501


class TestCatalogsApi(unittest.TestCase):
    """CatalogsApi unit test stubs"""

    def setUp(self):
        self.api = CatalogsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_product_to_catalog(self):
        """Test case for attach_product_to_catalog

        Addproducttocatalog  # noqa: E501
        """
        pass

    def test_create_catalog(self):
        """Test case for create_catalog

        Createcatalog  # noqa: E501
        """
        pass

    def test_delete_catalog(self):
        """Test case for delete_catalog

        Deletecatalog  # noqa: E501
        """
        pass

    def test_detach_product_from_catalog(self):
        """Test case for detach_product_from_catalog

        Removeproductfromcatalog  # noqa: E501
        """
        pass

    def test_get_catalog(self):
        """Test case for get_catalog

        Getcatalog  # noqa: E501
        """
        pass

    def test_search_catalog_products(self):
        """Test case for search_catalog_products

        Searchcatalogproducts  # noqa: E501
        """
        pass

    def test_search_catalogs(self):
        """Test case for search_catalogs

        Searchcatalogs  # noqa: E501
        """
        pass

    def test_update_catalog(self):
        """Test case for update_catalog

        Updatecatalog  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.attach_product_to_catalog import AttachProductToCatalog
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.create_catalog import CreateCatalog
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.delete_catalog import DeleteCatalog
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.detach_product_from_catalog import DetachProductFromCatalog
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.get_catalog import GetCatalog
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.search_catalog_products import SearchCatalogProducts
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.search_catalogs import SearchCatalogs
from ehelply_python_experimental_sdk.api.catalogs_api_endpoints.update_catalog import UpdateCatalog


class CatalogsApi(
    AttachProductToCatalog,
    CreateCatalog,
    DeleteCatalog,
    DetachProductFromCatalog,
    GetCatalog,
    SearchCatalogProducts,
    SearchCatalogs,
    UpdateCatalog,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.model.create_project_credit import CreateProjectCredit


class TestCreateProjectCredit(unittest.TestCase):
    """CreateProjectCredit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_CreateProjectCredit(self):
        """Test CreateProjectCredit"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateProjectCredit()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.products_api_endpoints.create_product import CreateProduct
from ehelply_python_experimental_sdk.api.products_api_endpoints.delete_product import DeleteProduct
from ehelply_python_experimental_sdk.api.products_api_endpoints.get_product import GetProduct
from ehelply_python_experimental_sdk.api.products_api_endpoints.search_product_catalog import SearchProductCatalog
from ehelply_python_experimental_sdk.api.products_api_endpoints.search_products import SearchProducts
from ehelply_python_experimental_sdk.api.products_api_endpoints.update_product import UpdateProduct


class ProductsApi(
    CreateProduct,
    DeleteProduct,
    GetProduct,
    SearchProductCatalog,
    SearchProducts,
    UpdateProduct,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.projects_api_endpoints.add_member_to_project import AddMemberToProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.archive_project import ArchiveProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project import CreateProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project_credential import CreateProjectCredential
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project_credit import CreateProjectCredit
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project_invoice import CreateProjectInvoice
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project_key import CreateProjectKey
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_usage_type import CreateUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_project_credential import DeleteProjectCredential
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_project_key import DeleteProjectKey
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_usage_type import DeleteUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_all_project_credentials import GetAllProjectCredentials
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_all_project_credits import GetAllProjectCredits
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_all_project_usage import GetAllProjectUsage
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_member_projects import GetMemberProjects
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project import GetProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_credit_transactions import GetProjectCreditTransactions
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_invoice import GetProjectInvoice
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_invoice_history import GetProjectInvoiceHistory
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_keys import GetProjectKeys
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_members import GetProjectMembers
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_specific_project_credential import GetSpecificProjectCredential
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_specific_project_usage import GetSpecificProjectUsage
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_usage_type import GetUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.remove_member_from_project import RemoveMemberFromProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.revoke_project_credit import RevokeProjectCredit
from ehelply_python_experimental_sdk.api.projects_api_endpoints.search_projects import SearchProjects
from ehelply_python_experimental_sdk.api.projects_api_endpoints.search_usage_type import SearchUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_project import UpdateProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_project_credential import UpdateProjectCredential
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_usage_type import UpdateUsageType


class ProjectsApi(
    AddMemberToProject,
    ArchiveProject,
    CreateProject,
    CreateProjectCredential,
    CreateProjectCredit,
    CreateProjectInvoice,
    CreateProjectKey,
    CreateUsageType,
    DeleteProjectCredential,
    DeleteProjectKey,
    DeleteUsageType,
    GetAllProjectCredentials,
    GetAllProjectCredits,
    GetAllProjectUsage,
    GetMemberProjects,
    GetProject,
    GetProjectCreditTransactions,
    GetProjectInvoice,
    GetProjectInvoiceHistory,
    GetProjectKeys,
    GetProjectMembers,
    GetSpecificProjectCredential,
    GetSpecificProjectUsage,
    GetUsageType,
    RemoveMemberFromProject,
    RevokeProjectCredit,
    SearchProjects,
    SearchUsageType,
    UpdateProject,
    UpdateProjectCredential,
    UpdateUsageType,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.tags_api_endpoints.create_tag import CreateTag
from ehelply_python_experimental_sdk.api.tags_api_endpoints.get_tag import GetTag
from ehelply_python_experimental_sdk.api.tags_api_endpoints.search_tag import SearchTag
from ehelply_python_experimental_sdk.api.tags_api_endpoints.update_tag import UpdateTag


class TagsApi(
    CreateTag,
    GetTag,
    SearchTag,
    UpdateTag,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.staff_api import StaffApi  # noqa: E501


class TestStaffApi(unittest.TestCase):
    """StaffApi unit test stubs"""

    def setUp(self):
        self.api = StaffApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staff(self):
        """Test case for create_staff

        Createstaff  # noqa: E501
        """
        pass

    def test_delete_staff(self):
        """Test case for delete_staff

        Deletestaff  # noqa: E501
        """
        pass

    def test_get_staff(self):
        """Test case for get_staff

        Getstaff  # noqa: E501
        """
        pass

    def test_search_staff(self):
        """Test case for search_staff

        Searchstaff  # noqa: E501
        """
        pass

    def test_update_staff(self):
        """Test case for update_staff

        Updatestaff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.products_api import ProductsApi  # noqa: E501


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = ProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_product(self):
        """Test case for create_product

        Createproduct  # noqa: E501
        """
        pass

    def test_delete_product(self):
        """Test case for delete_product

        Deleteproduct  # noqa: E501
        """
        pass

    def test_get_product(self):
        """Test case for get_product

        Getproduct  # noqa: E501
        """
        pass

    def test_search_product_catalog(self):
        """Test case for search_product_catalog

        Searchproductcatalog  # noqa: E501
        """
        pass

    def test_search_products(self):
        """Test case for search_products

        Searchproducts  # noqa: E501
        """
        pass

    def test_update_product(self):
        """Test case for update_product

        Updateproduct  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
